package xyz.mcutils.models.server;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.ToString;
import xyz.mcutils.models.dns.DNSRecord;

import java.util.UUID;

@Getter
public class MinecraftServer {
    /**
     * The hostname of the server.
     */
    private String hostname;

    /**
     * The IP address of the server.
     */
    private String ip;

    /**
     * The port of the server.
     */
    private int port;

    /**
     * The DNS records for the server.
     */
    private DNSRecord[] records;

    /**
     * The motd for the server.
     */
    private MOTD motd;

    /**
     * The players on the server.
     */
    private Players players;

    @AllArgsConstructor @Getter
    private static class MOTD {

        /**
         * The raw motd lines
         */
        private String[] raw;

        /**
         * The clean motd lines
         */
        private String[] clean;

        /**
         * The html motd lines
         */
        private String[] html;
    }

    /**
     * Player count data for a server.
     */
    @Getter
    private static class Players {
        /**
         * The online players on this server.
         */
        private int online;

        /**
         * The maximum allowed players on this server.
         */
        private int max;

        /**
         * A sample of players on this server, null or empty if no sample.
         */
        private Sample[] sample;

        /**
         * A sample player.
         */
        @Getter @ToString
        private static class Sample {
            /**
             * The unique id of this player.
             */
            private UUID id;

            /**
             * The name of this player.
             */
            private String name;
        }
    }
}
